@@ -1,6 +1,6 @@
       SUBROUTINE MULFRFF(K,INW,N,LAGH1,IP0,P,X,C,S,G,PH,PCH,R,CHM)
 C
-      INCLUDE 'timsac_f.h'
+      INCLUDE 'timsac.h'
 C
 C     PROGRAM 5.2.4   FREQUENCY RESPONSE FUNCTION (MULTIPLE CHANNEL)
 C-----------------------------------------------------------------------
@@ -29,9 +29,6 @@ C     PROGRAM 5.2.2 MULSPE TO FORM THE INPUT TO THIS PROGRAM.
 C     WITHIN IP0 VARIABLES OF MULSPE OUTPUT, ONLY THOSE K+1 INW(I)-TH
 C     VARIABLES ARE TAKEN INTO COMPUTATION.
 C
-cc      !DEC$ ATTRIBUTES DLLEXPORT :: MULFRFF
-c      USE DFLIB
-C
 cxx      IMPLICIT REAL*8(A-H,O-W)
 cxx      IMPLICIT COMPLEX*16(X-Z)
 c      DIMENSION P(10,10),X(10,10),C(10),S(10),G(10)
@@ -41,12 +38,13 @@ cxx      DIMENSION C(K,LAGH1),S(K,LAGH1),G(K,LAGH1)
 cxx      DIMENSION OARC(K),PH(K,LAGH1),PCH(K,LAGH1),R(K,LAGH1),INW(K+1)
 cxx      DIMENSION CHM(LAGH1)
 cxx      DIMENSION XFR(IP0,IP0,LAGH1)
-      INTEGER :: K, INW(K+1), N, LAGH1, IP0
-      REAL(8) :: P(LAGH1,IP0,IP0), C(K,LAGH1), S(K,LAGH1),
-     1           G(K,LAGH1), PH(K,LAGH1), PCH(K,LAGH1),
-     2           R(K,LAGH1), CHM(LAGH1)
+      INTEGER K, INW(K+1), N, LAGH1, IP0
+      DOUBLE PRECISION P(LAGH1,IP0,IP0), C(K,LAGH1), S(K,LAGH1),
+     1                 G(K,LAGH1), PH(K,LAGH1), PCH(K,LAGH1),
+     2                 R(K,LAGH1), CHM(LAGH1)
       COMPLEX(kind(0d0)) :: X(IP0,IP0,LAGH1)
-      REAL(8) :: OARC(K), P00, EP, G2, G3, D1, D2
+c local
+      DOUBLE PRECISION OARC(K), P00, EP, G2, G3, D1, D2
       COMPLEX(kind(0d0)) :: XFR(IP0,IP0,LAGH1), XDET
 C
 C     INPUT / OUTPUT DATA FILE OPEN
@@ -181,9 +179,9 @@ cxx      IMPLICIT COMPLEX*16(X)
 cxx      DIMENSION X(MJ,MJ)
 cx      DIMENSION IDS(10)
 cxx      DIMENSION IDS(MM)
-      INTEGER :: MM, MJ
+      INTEGER MM, MJ
       COMPLEX(kind(0d0)) :: X(MJ,MJ), XDET
-      INTEGER :: IDS(MM)
+      INTEGER IDS(MM)
       COMPLEX(kind(0d0)) :: XMAXP, XC
 C
       XDET=1.0D-00
@@ -252,9 +250,9 @@ cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION C(K),S(K),OARC(K),PH(K)
 c      DIMENSION ARC(10)
 cxx      DIMENSION ARC(K)
-      INTEGER :: K, JJF
-      REAL(8) :: C(K), S(K), OARC(K), PH(K)
-      REAL(8) :: ARC(K)
+      INTEGER K, JJF
+      DOUBLE PRECISION C(K), S(K), OARC(K), PH(K)
+      DOUBLE PRECISION ARC(K)
 C     ARCTANGENT COMPUTATION
       CALL MULARC(C,S,ARC,K)
 C     PHASE COMPUTATION
@@ -267,9 +265,9 @@ C     THIS SUBROUTINE COMPUTES RAW PHASE.
 C     (MULTIPLE CHANNEL)
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION C(K),S(K),ARC(K)
-      INTEGER :: K
-      REAL(8) :: C(K), S(K), ARC(K)
-      REAL(8) :: PI, CST5
+      INTEGER K
+      DOUBLE PRECISION C(K), S(K), ARC(K)
+      DOUBLE PRECISION PI, CST5
       PI=3.1415926536
       CST5=0.5D-00
       DO 10 I=1,K
@@ -307,9 +305,9 @@ C     THIS SUBROUTINE COMPUTES RELATIVE ERROR STATISTICS.
 C     (MULTIPLE CHANNEL)
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION PCH(K),R(K)
-      INTEGER :: N, LAGH1, K,JJF
-      REAL(8) :: PCH(K), R(K), D1, D2
-      REAL(8) :: CST0, CST1, CST100, E1, ER
+      INTEGER N, LAGH1, K,JJF
+      DOUBLE PRECISION PCH(K), R(K), D1, D2
+      DOUBLE PRECISION CST0, CST1, CST100, E1, ER
       CST0=0.0D-00
       CST1=1.0D-00
       CST100=100.0D-00
@@ -339,9 +337,9 @@ C     THIS SUBROUTINE MAKES PHASE CURVE CONTINUOUS.
 C     (MULTIPLE CHANNEL)
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION ARC(K),OARC(K),PH(K)
-      INTEGER :: K, JJF
-      REAL(8) :: ARC(K), OARC(K), PH(K)
-      REAL(8) :: PI, PI2, DK
+      INTEGER K, JJF
+      DOUBLE PRECISION ARC(K), OARC(K), PH(K)
+      DOUBLE PRECISION PI, PI2, DK
       PI=3.1415926536
       PI2=PI+PI
       IF(JJF.NE.1) GO TO 20
