@@ -1,8 +1,7 @@
       SUBROUTINE NONSTF(N,ISTP,DATA0,NM,LAGH,JP0,COEF0,VA0,AIC0,DAIC21,
-cx     *                  DAIC,K01,KOUNT2,SXX,TMP,IER)
      *                  DAIC,K01,KOUNT2,SXX)
 C
-      INCLUDE 'timsac_f.h'
+      INCLUDE 'timsac.h'
 C
 cc      PROGRAM NONST
 C     PROGRAM 74.4.1. NON-STATIONARY POWER SPECTRUM ANALYSIS
@@ -29,8 +28,6 @@ C         ISTP : LENGTH OF THE BASIC LOCAL SPAN
 C         DFORM : INPUT FORMAT SPECIFICATION IN ONE CARD, FOR EXAMPLE,'(8
 C         (X(I),I=1,N) : ORIGINAL DATA.
 C
-cc      !DEC$ ATTRIBUTES DLLEXPORT :: NONSTF
-C
 C     NSG : NUMBER OF SEGMENTS OF FREQUENCY AXIS +1
       PARAMETER (NSG=121)
 C
@@ -50,14 +47,15 @@ cxx      DIMENSION CN(LAGH+1)
 cxx      DIMENSION JP0(NM)
 cxx      DIMENSION VA0(NM),AIC0(NM),DAIC21(NM),DAIC(NM)
 cxx      DIMENSION K01(NM),KOUNT2(NM)
-      INTEGER :: N, ISTP, NM, LAGH, JP0(NM), K01(NM), KOUNT2(NM)
-      REAL(8) :: DATA0(N), COEF0(LAGH,NM), VA0(NM), AIC0(NM),
-     1           DAIC21(NM), DAIC(NM), SXX(NSG,NM)
-      INTEGER :: IDX(5)
-      REAL(8) :: ACV0(LAGH+1), ACV1(LAGH+1), ACV2(LAGH+1),
-     1           COEF1(LAGH), COEF2(LAGH), DATA1(N), CN(LAGH+1),
-     2           AISTP, AIP0, AIP1, AIP2, CST2, CST4, ANI, ANJ, STP,
-     3           VA1, VA2, AIC1, AIC2, XMEAN, Z
+      INTEGER N, ISTP, NM, LAGH, JP0(NM), K01(NM), KOUNT2(NM)
+      DOUBLE PRECISION DATA0(N), COEF0(LAGH,NM), VA0(NM), AIC0(NM),
+     1                 DAIC21(NM), DAIC(NM), SXX(NSG,NM)
+c local
+      INTEGER IDX(5)
+      DOUBLE PRECISION ACV0(LAGH+1), ACV1(LAGH+1), ACV2(LAGH+1),
+     1                 COEF1(LAGH), COEF2(LAGH), DATA1(N), CN(LAGH+1),
+     2                 AISTP, AIP0, AIP1, AIP2, CST2, CST4, ANI, ANJ,
+     3                 STP, VA1, VA2, AIC1, AIC2, XMEAN, Z
 C
 cx      INTEGER*1  TMP(1)
 cx      CHARACTER  CNAME*80
@@ -364,10 +362,10 @@ C     COEF; AR-COEFFICIENTS
 cxx      IMPLICIT REAL*8(A-H,O-Z)
 cxx      DIMENSION CXX(L1),COEF(L1)
 cc	DIMENSION A(500),B(500)
-      INTEGER :: L1, N, MO
-      REAL(8) :: CXX(L1), COEF(L1), OSD
-      REAL(8) :: A(L1-1),B(L1-1), CST1, CST2, SD, AN, OAIC, SE, D, D2,
-     1           AM, DLSD, AIC
+      INTEGER L1, N, MO
+      DOUBLE PRECISION CXX(L1), COEF(L1), OSD
+      DOUBLE PRECISION A(L1-1),B(L1-1), CST1, CST2, SD, AN, OAIC, SE,
+     1                 D, D2, AM, DLSD, AIC
       CST1=1.0D-00
       CST2=2.0D-00
       L=L1-1
